@@ -12,7 +12,7 @@ Links:
 import sys
 from pathlib import Path
 import os
-import json
+
 from requests import Session
 from requests.auth import HTTPBasicAuth
 import re
@@ -59,6 +59,7 @@ class axl(object):
         transport = Transport(session=session, timeout=10, cache=SqliteCache())
         axl_client = Client(wsdl, settings=settings, transport=transport)
 
+        self.wsdl = wsdl
         self.username = username
         self.password = password
         self.wsdl = wsdl
@@ -93,33 +94,6 @@ class axl(object):
         except Fault as e:
             return e
 
-    def run_sql_query(self, query):
-        result = {"num_rows": 0, "query": query}
-
-        try:
-            sql_result = self.client.executeSQLQuery(sql=query)
-            print(sql_result)
-        except Exception as fault:
-            sql_result = None
-            self.last_exception = fault
-
-        num_rows = 0
-        result_rows = []
-
-        if sql_result is not None:
-            if sql_result["return"] is not None:
-                for row in sql_result["return"]["row"]:
-                    result_rows.append({})
-                    for column in row:
-                        result_rows[num_rows][column.tag] = column.text
-                    num_rows += 1
-
-        result["num_rows"] = num_rows
-        if num_rows > 0:
-            result["rows"] = result_rows
-
-        return result
-
     def sql_query(self, query):
         """
         Execute SQL query
@@ -142,22 +116,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_ldap_dir(
-        self,
-        tagfilter={
-            "name": "",
-            "ldapDn": "",
-            "userSearchBase": "",
-        },
-    ):
+    def get_ldap_dir(self, tagfilter={"name": "", "ldapDn": "", "userSearchBase": "",}):
         """
         Get LDAP Syncs
         :return: result dictionary
         """
         try:
             return self.client.listLdapDirectory(
-                {"name": "%"},
-                returnedTags=tagfilter,
+                {"name": "%"}, returnedTags=tagfilter,
             )["return"]["ldapDirectory"]
         except Fault as e:
             return e
@@ -370,7 +336,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getRegion(**args)["return"]["region"]
+            return self.client.getRegion(**args)
         except Fault as e:
             return e
 
@@ -470,14 +436,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_srst(self, **args):
+    def get_srst(self, name):
         """
         Get SRST information
         :param name: SRST name
         :return: result dictionary
         """
         try:
-            return self.client.getSrst(**args)["return"]["srst"]
+            return self.client.getSrst(name=name)
         except Fault as e:
             return e
 
@@ -556,7 +522,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getDevicePool(**args)["return"]["devicePool"]
+            return self.client.getDevicePool(**args)
         except Fault as e:
             return e
 
@@ -656,20 +622,19 @@ class axl(object):
         """
         try:
             return self.client.listConferenceBridge(
-                {"name": "%"},
-                returnedTags=tagfilter,
+                {"name": "%"}, returnedTags=tagfilter,
             )["return"]["conferenceBridge"]
         except Fault as e:
             return e
 
-    def get_conference_bridge(self, **args):
+    def get_conference_bridge(self, name):
         """
         Get conference bridge parameters
         :param name: conference bridge name
         :return: result dictionary
         """
         try:
-            return self.client.getConferenceBridge(**args)["return"]["conferenceBridge"]
+            return self.client.getConferenceBridge(name=name)
         except Fault as e:
             return e
 
@@ -749,14 +714,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_transcoder(self, **args):
+    def get_transcoder(self, name):
         """
         Get conference bridge parameters
         :param name: transcoder name
         :return: result dictionary
         """
         try:
-            return self.client.getTranscoder(**args)["return"]["transcoder"]
+            return self.client.getTranscoder(name=name)
         except Fault as e:
             return e
 
@@ -826,14 +791,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_mtp(self, **args):
+    def get_mtp(self, name):
         """
         Get mtp parameters
         :param name: transcoder name
         :return: result dictionary
         """
         try:
-            return self.client.getMtp(**args)["return"]["mtp"]
+            return self.client.getMtp(name=name)
         except Fault as e:
             return e
 
@@ -912,14 +877,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_h323_gateway(self, **args):
+    def get_h323_gateway(self, name):
         """
         Get H323 Gateway parameters
         :param name: H323 Gateway name
         :return: result dictionary
         """
         try:
-            return self.client.getH323Gateway(**args)["return"]["h323Gateway"]
+            return self.client.getH323Gateway(name=name)
         except Fault as e:
             return e
 
@@ -1006,7 +971,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getRouteGroup(**args)["return"]["routeGroup"]
+            return self.client.getRouteGroup(**args)
         except Fault as e:
             return e
 
@@ -1056,7 +1021,7 @@ class axl(object):
         Update a Route group
         :param name: The name of the Route group to update
         :param distribution_algorithm: Top Down/Circular
-        :param members: A list of devices to add (must already exist DUH!)
+        :param members: A list of devices to add (must already exist DUH!)        
         :return: result dictionary
         """
         try:
@@ -1085,7 +1050,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getRouteList(**args)["return"]["routeList"]
+            return self.client.getRouteList(**args)
         except Fault as e:
             return e
 
@@ -1194,7 +1159,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getRoutePartition(**args)["return"]["routePartition"]
+            return self.client.getRoutePartition(**args)
         except Fault as e:
             return e
 
@@ -1258,7 +1223,7 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_calling_search_space(self, **args):
+    def get_calling_search_space(self, **css):
         """
         Get Calling search space details
         :param name: Calling search space name
@@ -1266,7 +1231,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getCss(**args)["return"]["css"]
+            return self.client.getCss(**css)
         except Fault as e:
             return e
 
@@ -1286,10 +1251,7 @@ class axl(object):
         if members:
             [
                 req["members"]["member"].append(
-                    {
-                        "routePartitionName": i,
-                        "index": members.index(i) + 1,
-                    }
+                    {"routePartitionName": i, "index": members.index(i) + 1,}
                 )
                 for i in members
             ]
@@ -1337,8 +1299,7 @@ class axl(object):
         """
         try:
             return self.client.listRoutePattern(
-                {"pattern": "%"},
-                returnedTags=tagfilter,
+                {"pattern": "%"}, returnedTags=tagfilter,
             )["return"]["routePattern"]
         except Fault as e:
             return e
@@ -1361,9 +1322,7 @@ class axl(object):
             if "return" in uuid and uuid["return"] is not None:
                 uuid = uuid["return"]["routePattern"][0]["uuid"]
                 try:
-                    return self.client.getRoutePattern(uuid=uuid)["return"][
-                        "routePattern"
-                    ]
+                    return self.client.getRoutePattern(uuid=uuid)
                 except Fault as e:
                     return e
 
@@ -1465,16 +1424,14 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_media_resource_group(self, **args):
+    def get_media_resource_group(self, name):
         """
         Get a media resource group details
         :param media_resource_group: Media resource group name
         :return: result dictionary
         """
         try:
-            return self.client.getMediaResourceGroup(**args)["return"][
-                "mediaResourceGroup"
-            ]
+            return self.client.getMediaResourceGroup(name=name)
         except Fault as e:
             return e
 
@@ -1600,12 +1557,7 @@ class axl(object):
             return e
 
     def get_directory_numbers(
-        self,
-        tagfilter={
-            "pattern": "",
-            "description": "",
-            "routePartitionName": "",
-        },
+        self, tagfilter={"pattern": "", "description": "", "routePartitionName": "",}
     ):
         """
         Get directory numbers
@@ -1627,7 +1579,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getLine(**args)["return"]["line"]
+            return self.client.getLine(**args)
         except Fault as e:
             return e
 
@@ -1798,7 +1750,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getCtiRoutePoint(**args)["return"]["ctiRoutePoint"]
+            return self.client.getCtiRoutePoint(**args)
         except Fault as e:
             return e
 
@@ -1904,7 +1856,8 @@ class axl(object):
 
     def get_phones(
         self,
-        query={"name": "%"},
+        first=1000,
+        skip=0,
         tagfilter={
             "name": "",
             "product": "",
@@ -1914,23 +1867,29 @@ class axl(object):
             "callingSearchSpaceName": "",
         },
     ):
-        skip = 0
-        a = []
+        """
+        Get phone details
+        :param mini: return a list of tuples of phone details
+        :return: A list of dictionaries. If > 1000 records are returned, a list of list of dictionaries will be returned
+        """
+        paginated = []
+        try:
+            return self.client.listPhone(
+                {"name": "%"}, returnedTags=tagfilter, first=first, skip=skip
+            )["return"]["phone"]
+        except Fault as e:
+            return e
 
-        def inner(skip):
-            while True:
-                res = self.client.listPhone(
-                    searchCriteria=query, returnedTags=tagfilter, first=1000, skip=skip
-                )["return"]
-                skip = skip + 1000
-                if res is not None and "phone" in res:
-                    yield res["phone"]
+            if len(resp) >= 1000:
+                skip = first + skip
+                first += first
+                paginated.append(resp)
+                self.get_phones(first=first, skip=skip)
+            else:
+                if first > 1000:
+                    return paginated
                 else:
-                    break
-
-        for each in inner(skip):
-            a.extend(each)
-        return a
+                    return resp
 
     def get_phone(self, **args):
         """
@@ -2113,12 +2072,7 @@ class axl(object):
 
     def get_device_profiles(
         self,
-        tagfilter={
-            "name": "",
-            "product": "",
-            "protocol": "",
-            "phoneTemplateName": "",
-        },
+        tagfilter={"name": "", "product": "", "protocol": "", "phoneTemplateName": "",},
     ):
         """
         Get device profile details
@@ -2127,8 +2081,7 @@ class axl(object):
         """
         try:
             return self.client.listDeviceProfile(
-                {"name": "%"},
-                returnedTags=tagfilter,
+                {"name": "%"}, returnedTags=tagfilter,
             )["return"]["deviceProfile"]
         except Fault as e:
             return e
@@ -2141,7 +2094,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getDeviceProfile(**args)["return"]["deviceProfile"]
+            return self.client.getDeviceProfile(**args)
         except Fault as e:
             return e
 
@@ -2245,28 +2198,19 @@ class axl(object):
         except Fault as e:
             return e
 
-    def get_users(self, tagfilter={"userid": "", "firstName": "", "lastName": ""}):
+    def get_users(self, tagfilter={"userid": "", "firstName": "", "lastName": "",}):
         """
         Get users details
+        :param mini: return a list of tuples of user details
         :return: A list of dictionary's
         """
-        skip = 0
-        a = []
 
-        def inner(skip):
-            while True:
-                res = self.client.listUser(
-                    {"userid": "%"}, returnedTags=tagfilter, first=1000, skip=skip
-                )["return"]
-                skip = skip + 1000
-                if res is not None and "user" in res:
-                    yield res["user"]
-                else:
-                    break
-
-        for each in inner(skip):
-            a.extend(each)
-        return a
+        try:
+            return self.client.listUser({"userid": "%"}, returnedTags=tagfilter)[
+                "return"
+            ]["user"]
+        except Fault as e:
+            return e
 
     def get_user(self, userid):
         """
@@ -2695,9 +2639,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getCalledPartyTransformationPattern(**args)["return"][
-                "calledPartyTransformationPattern"
-            ]
+            return self.client.getCalledPartyTransformationPattern(**args)
         except Fault as e:
             return e
 
@@ -2707,7 +2649,7 @@ class axl(object):
         description="",
         partition="",
         calledPartyPrefixDigits="",
-        calledPartyTransformationMask="",
+        calledPartyTransformationmask="",
         digitDiscardInstructionName="",
     ):
         """
@@ -2732,7 +2674,7 @@ class axl(object):
                     "description": description,
                     "routePartitionName": partition,
                     "calledPartyPrefixDigits": calledPartyPrefixDigits,
-                    "calledPartyTransformationMask": calledPartyTransformationMask,
+                    "calledPartyTransformationmask": calledPartyTransformationmask,
                     "digitDiscardInstructionName": digitDiscardInstructionName,
                 }
             )
@@ -2798,9 +2740,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getCallingPartyTransformationPattern(**args)["return"][
-                "callingPartyTransformationPattern"
-            ]
+            return self.client.getCallingPartyTransformationPattern(**args)
         except Fault as e:
             return e
 
@@ -2810,7 +2750,7 @@ class axl(object):
         description="",
         partition="",
         callingPartyPrefixDigits="",
-        callingPartyTransformationMask="",
+        callingPartyTransformationmask="",
         digitDiscardInstructionName="",
     ):
         """
@@ -2835,7 +2775,7 @@ class axl(object):
                     "description": description,
                     "routePartitionName": partition,
                     "callingPartyPrefixDigits": callingPartyPrefixDigits,
-                    "callingPartyTransformationMask": callingPartyTransformationMask,
+                    "callingPartyTransformationmask": callingPartyTransformationmask,
                     "digitDiscardInstructionName": digitDiscardInstructionName,
                 }
             )
@@ -2862,7 +2802,7 @@ class axl(object):
         :param pattern: pattern - required
         :param routePartitionName: partition required
         :param description: Route pattern description
-        :param callingPartyTransformationMask:
+        :param calledPartyTransformationmask:
         :param dialPlanName:
         :param digitDiscardInstructionName:
         :param routeFilterName:
@@ -2896,7 +2836,7 @@ class axl(object):
         :return: result dictionary
         """
         try:
-            return self.client.getSipTrunk(**args)["return"]["sipTrunk"]
+            return self.client.getSipTrunk(**args)
         except Fault as e:
             return e
 
@@ -3027,51 +2967,3 @@ class axl(object):
             return self.client.removeCallManagerGroup({"name": name})
         except Fault as e:
             return e
-
-    def get_hunt_pilots(
-        self,
-        tagfilter={
-            "pattern": "",
-            "description": "",
-            "routePartitionName": "",
-        },
-    ):
-        """
-        Get hunt pilots
-        :param mini: return a list of tuples of hunt pilot details
-        :return: A list of dictionary's
-        """
-        try:
-            return self.client.listHuntPilot({"pattern": "%"}, returnedTags=tagfilter,)[
-                "return"
-            ]["huntPilot"]
-        except Fault as e:
-            return e
-
-    def get_hunt_pilot(self, **args):
-        """
-        Get hunt pilot details
-        :param name:
-        :param partition:
-        :return: result dictionary
-        """
-        try:
-            return self.client.getHuntPilot(**args)["return"]["huntPilot"]
-        except Fault as e:
-            return e
-
-    def add_hunt_pilot(self, **args):
-        """
-        Add a Hunt Pilot minimal params needed
-        :param pattern: pattern - required
-        :param routePartitionName: partition required
-        :param description: Hunt Pilot pattern description
-        :param useCallingPartyPhoneMask: "Off" or "On"
-        :param blockEnable: boolean (true or false)
-        :param huntListName:
-        :return: result dictionary
-        """
-        try:
-            return self.client.addHuntPilot({**args})
-        except Fault as e:
-            return e
